@@ -32,7 +32,7 @@
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.16'
+__version__ = '0.17'
 
 
 DEFAULT_TTL = 3600
@@ -60,13 +60,6 @@ class Acl(core_flags.CoreFlags):
       self.AddFlagRule(('force', 'cidr_block'), flag_type='independent_args',
                        required=False)
 
-    self.parser.add_option('--allow', action='store_true', dest='allow',
-                           help='Allow CIDR block in ACL.', default=None)
-    self.parser.add_option('--deny', action='store_true', dest='deny',
-                           help='Deny CIDR block in ACL.', default=None)
-    self.AddFlagRule(('allow', 'deny'), required=self.action=='Make',
-                     flag_type='independent_args')
-
 
 class Record(core_flags.CoreFlags):
   """Command line record flags"""
@@ -294,6 +287,14 @@ class View(core_flags.CoreFlags):
     self.parser.add_option('-a', '--acl', action='store', dest='acl',
                            help='String of access control list name.',
                            default=None)
+    self.parser.add_option('--allow', action='store_true', dest='allow',
+                           help='Allow ACL in view.', default=None)
+    self.parser.add_option('--deny', action='store_true', dest='deny',
+                           help='Deny ACL in view.', default=None)
+    self.AddFlagRule(('allow', 'deny'), required=self.action=='Make',
+                     flag_type='independent_args', command='view')
+    self.AddFlagRule(('allow', 'deny'), required=self.action=='Make',
+                     flag_type='independent_args', command='acl')
     if( self.action != 'Remove' ):
       self.AddFlagRule('acl', required=not_list, command='view')
     self.AddFlagRule('acl', required=not_list, command='acl')
@@ -327,12 +328,19 @@ class Host(core_flags.CoreFlags):
                            metavar='<cidr-block>', default=None)
     if( self.action == 'Make' ):
       self.AddFlagRule('cidr_block', required=True, command='findfirst')
+    elif( not not_list ):
+      self.AddFlagRule('cidr_block', required=True, command='cidr')
     else:
       self.AddFlagRule('cidr_block', required=False)
     self.parser.add_option('-z', '--zone-name', action='store',
                            dest='zone_name', help='String of the zone name.',
                            metavar='<zone-name>', default=None)
-    self.AddFlagRule('zone_name', required=not_list)
+    if( not_list ):
+      self.AddFlagRule('zone_name', required=True)
+    else:
+      self.AddFlagRule('zone_name', required=True, command='zone')
+      self.AddFlagRule('zone_name', required=False, command='cidr')
+
     if( not_list ):
       default_view = u'any'
     else:
@@ -363,23 +371,11 @@ class DnsServer(core_flags.CoreFlags):
                      command='dns_server_set')
     self.AddFlagRule('dns_server_set', required=not_list, command='assignment')
 
-
-class User(core_flags.CoreFlags):
-  """Command line user flags"""
+class Group(core_flags.CoreFlags):
+  """Command line group flags"""
   def SetDataFlags(self):
     """Sets flags for self.parser"""
     not_list = self.action != 'List'
-    self.parser.add_option('-n', '--new-user', action='store', dest='new_user',
-                           help='String of the new user to create.',
-                           metavar='<new-user>', default=None)
-    self.AddFlagRule('new_user', required=not_list, command='user')
-    self.AddFlagRule('new_user', required=not_list, command='assignment')
-    self.parser.add_option('-a', '--access-level', action='store',
-                           dest='access_level',
-                           help='Access level of new user.',
-                           metavar='<access-level>', default=None, type='int')
-    self.AddFlagRule('access_level', required=self.action=='Make',
-                     command='user')
     self.parser.add_option('-g', '--group', action='store', dest='group',
                            help='String of the group name to create or assign.',
                            metavar='<group>', default=None)
@@ -392,18 +388,45 @@ class User(core_flags.CoreFlags):
                            help='String of the zone name (optional)',
                            metavar='<zone>', default=None)
     self.AddFlagRule('zone_name', required=not_list, command='forward')
-    self.AddFlagRule('zone_name', required=not_list, command='reverse')
-    self.parser.add_option('--access-right', action='store',
-                           dest='access_right',
-                           help='String of the access right (r/rw)',
-                           metavar='r|rw', default=None)
-    self.AddFlagRule('access_right', required=not_list, command='forward')
-    self.AddFlagRule('access_right', required=not_list, command='reverse')
+    spouse_classes = [base.__name__ for base in self.__class__.__bases__]
+    if( 'Remove' not in spouse_classes ):
+      self.parser.add_option('--group-permission', action='store',
+                             dest='group_permission',
+                             help='String of comma-separated group permissions, '
+                                  'e.g., a,aaaa,cname',
+                             metavar='<group-permission>', default=None)
+      self.AddFlagRule('group_permission', required=not_list, command='forward')
+      self.AddFlagRule('group_permission', required=not_list, command='reverse')
     self.parser.add_option('-b', '--cidr-block', action='store',
                            dest='cidr_block', help='String of CIDR block.',
                            metavar='<cidr-block>', default=None)
     self.AddFlagRule('cidr_block', required=not_list, command='reverse')
 
+class User(Group):
+  """Command line user flags
+    The User class inherits all of Group's flags so dnsupusergroup has the 
+    option of not including flags it doesn't need. So know that if you call
+    User.SetDataFlags(), you'll get both Users' and Group's
+
+  Used by:
+    dnsupusergroup
+  """
+  def SetDataFlags(self):
+    """Sets flags for self.parser"""
+    not_list = self.action != 'List'
+    self.parser.add_option('-n', '--new-user', action='store', dest='new_user',
+                           help='String of the new user to create.',
+                           metavar='<new-user>', default=None)
+    self.AddFlagRule('new_user', required=not_list, command='user')
+    self.AddFlagRule('new_user', required=not_list, command='assignment')
+    self.parser.add_option('-a', '--access-level', action='store',
+                           dest='access_level',
+                           help='Access level of new user.',
+                           metavar='<access-level>',
+                           default=None)
+    self.AddFlagRule('access_level', required=self.action=='Make',
+                     command='user')
+    super(User, self).SetDataFlags()
 
 class Hosts(core_flags.CoreFlags):
   """Command line uphost flags"""
@@ -512,7 +535,7 @@ class NamedGlobals(core_flags.CoreFlags):
     self.AddFlagRule('dns_server_set', required=True, command='update')
     self.AddFlagRule('dns_server_set', required=True, command='list')
     self.AddFlagRule('dns_server_set', required=True, command='revert')
-    self.AddFlagRule('dns_server_set', required=True, command='edit')
+    self.AddFlagRule('dns_server_set', required=False, command='edit')
     self.parser.add_option('-i', '--option-id', action='store',
                            dest='option_id',
                            help='Integer of option id.', metavar='<option-id>',
@@ -520,9 +543,10 @@ class NamedGlobals(core_flags.CoreFlags):
     self.AddFlagRule('option_id', required=False, command='list')
     self.AddFlagRule('option_id', required=False, command='dump')
     self.AddFlagRule('option_id', required=True, command='revert')
+    self.AddFlagRule('option_id', required=False, command='edit')
     self.parser.add_option('-t', '--timestamp', action='store',
                            dest='timestamp',
-                           help='String of timestamp in YYYY/MM/DD/HH/MM/SS '
+                           help='String of timestamp in YYYY-MM-DDTHH:MM:SS '
                                 'format.', metavar='<timestamp>', default=None)
     self.AddFlagRule('timestamp', required=False, command='list')
     self.AddFlagRule('timestamp', required=False, command='dump')
